//=====================================================
// Client Side scripts (JavaScript) for IBM Multimedia Analysis and Retrieval System
//
// Copyright (c) 2005, IBM T.J. Watson Research Center.
// All rights reserved.
//=====================================================


var id, timeID, obj;              // globals for mouseover effect (large image)
var mouseX, mouseY;               // mouse click coordinates
var LargeImage=false;             // Is the large image currently being displayed?
var MoveImage=false;              // Is the large image currently being moved?
var ImgZoomFactor=2;              // The current zoom factor for large image, default = 2
var CurImg=-1;                    // current image (for "virtual" cursor)
var X = 0, vertOffset = 0;        // user-settable vertical position for tooltip window
var Y = 0, horizOffset = 0;       // user-settable horizontal position for tooltip window
var tooltipObj;                   // reference to the tooltip object
var Wsize, Wscroll;               // browser window size and scroll information

// ----- The following should rather be constants but IE does not know constants :( ------

var MAX_ZOOM = 8;                 // Constants for zoom image handling
var MIN_ZOOM = 1;
var ZOOM_INC = 0.25;

//------------------------------------------------
// Initializes at the beginning, 
// must be called in <body onload="")>.
//------------------------------------------------
function Initialize()
{
    LargeImage = false;
    Wsize = getScreenSize();
    Wscroll = getScrollXY();
    tooltipObj = document.getElementById("tooltip");
    tooltipObj.style.visibility = "hidden";
    tooltipObj.style.backgroundColor = "rgb(238,238,238)";
    tooltipObj.style.border = "solid rgb(255,255,0) 6px"; 
    tooltipObj.style.padding = "10px";
    tooltipObj.style.position = "absolute";
    tooltipObj.style.width = "25%";
    tooltipObj.style.zIndex = 100;
    document.getElementById("speech").style.overflow = "auto";
    document.getElementById("speech").style.width = "100%";
}

//------------------------------------------------
// returns the current browser window size
//------------------------------------------------
function getScreenSize()
{
  var W = 0, H = 0;
  
  if( typeof( window.innerWidth ) == 'number' )
  {
    // non-Microsoft browsers
    W = window.innerWidth;
    H = window.innerHeight;
  } 
  else if( document.documentElement 
           && (document.documentElement.clientWidth || document.documentElement.clientHeight ) 
          ) 
  {
    //IE 6+ in 'standards compliant mode'
    W = document.documentElement.clientWidth;
    H = document.documentElement.clientHeight;
  }
  else if( document.body
           && (document.body.clientWidth || document.body.clientHeight ) 
          )
  {
    // IE 4 and compatible
    W = document.body.clientWidth;
    H = document.body.clientHeight;
  }
  return [W,H];
}


//------------------------------------------------
// returns the current scroll offset in pixel for
// both directions
//------------------------------------------------
function getScrollXY() 
{
  var scrOfX = 0, scrOfY = 0;
  if( typeof( window.pageYOffset ) == 'number' )
  {
    //Netscape compliant
    scrOfY = window.pageYOffset;
    scrOfX = window.pageXOffset;
  } 
  else if( document.body &&( document.body.scrollLeft || document.body.scrollTop ) ) 
  {
    //DOM compliant
    scrOfY = document.body.scrollTop;
    scrOfX = document.body.scrollLeft;
  }
  else if( document.documentElement &&
      ( document.documentElement.scrollLeft || document.documentElement.scrollTop ) ) {
    //IE6 standards compliant mode
    scrOfY = document.documentElement.scrollTop;
    scrOfX = document.documentElement.scrollLeft;
  }
  return [ scrOfX, scrOfY ];
}


function OnMouseOver(e)
{
  var targ;
  if (!e) var e = window.event;
  if (e.shiftKey==1) 
  {
    if (e.target) targ = e.target;
    else if (e.srcElement) targ = e.srcElement;
    obj = targ;
    CurImg = obj.id.substr(3,10);
      
//    if (LargeImage)
      timeID = window.setTimeout("ShowLargeImage()", 0);
  }
}
	

function OnMouseOut()
{
  HideLargeImage();
}
	

function OnMouseDown(e)
{
  var targ;
  if (!e) var e = window.event;
  if (e.target) targ = e.target;
  else if (e.srcElement) targ = e.srcElement;
  if (targ.id == "lrgimg")
  {
	MoveImage = true;
    mouseX = e.clientX;
    mouseY = e.clientY;
    
    // get current tooltip window position
    X = parseInt(tooltipObj.style.left+0); 
    Y = parseInt(tooltipObj.style.top+0);
  }
}
	

function OnMouseMove(e)
{
  if (MoveImage) 
  {
    if (!e) var e = window.event;
    // move tooltip window position
    tooltipObj.style.left = X + e.clientX - mouseX;
    tooltipObj.style.top = Y + e.clientY - mouseY;
  }
}
	

function OnMouseUp()
{
  MoveImage = false;

  // remember current tooltip window position relative to scroll
  X = parseInt(tooltipObj.style.left+0) - Wscroll[0];
  Y = parseInt(tooltipObj.style.top+0) - Wscroll[1];
  
  // adjust position relative to center of browser window 
//  var objWidth = parseInt(tooltipObj.style.width+0);
//  var objHeight = parseInt(tooltipObj.style.height+0) - 100;
//  X -= Wsize[0]/2 - objWidth/2; 
//  Y -= Wsize[1]/2 - objHeight/2; 
//  alert("X: " + X + ", Y: " + Y + ", scrollX: " + Wscroll[0] + ", scrollY: " + Wscroll[1]);
}


function OnMouseClick(e)
{
  if (MoveImage) OnMouseUp(e);
  else OnMouseDown(e);
}


function OnResizeOrScroll()
{
  if (LargeImage) ShowLargeImage();
}


//document.onmousedown = OnMouseDown;
//document.onmouseup = OnMouseUp;
document.onclick = OnMouseClick;
document.onmousemove = OnMouseMove;


//----------------------------------------------------
//  Replace a token in a string
//    s  string to be processed
//    t  token to be found and removed
//    u  token to be inserted
//  returns new String with all occurrencies of t replaced by u
//----------------------------------------------------
function replace(s, t, u) {
  i = s.indexOf(t);
  r = "";
  if (i == -1) return s;
  r += s.substring(0,i) + u;
  if ( i + t.length < s.length)
    r += replace(s.substring(i + t.length, s.length), t, u);
  return r;
}


//----------------------------------------------------
// Displays a large version of the currently 
// pointed image in an overlay area (like a tooltip)
//----------------------------------------------------
function ShowLargeImage()
{
  if (CurImg >= 0)
  {
    var imgID = obj.id;
    var oldID = imgID.substr(3,10);
    var newID = CurImg;
    var frmID = "frm" + oldID;
    var txtID = "txt" + oldID;
    var frmSrc = document.getElementById(frmID).value;
    var txtSrc = document.getElementById(txtID).value;
    var oldDir = Math.floor(oldID/100) * 100;
    var newDir = Math.floor(newID/100) * 100;
    frmSrc = replace(frmSrc, oldDir + "/" + oldID + ".", newDir + "/" + newID + ".");
    txtSrc = replace(txtSrc, oldDir + "/" + oldID + ".", newDir + "/" + newID + ".");

    // update large image and corresponding text
    document.getElementById("lrgimg").src = frmSrc;
    document.getElementById("lrgimg").style.width = ImgZoomFactor * obj.width;
    document.getElementById("lrgimg").style.height = ImgZoomFactor * obj.height;
    document.getElementById("speech").src = txtSrc;
    document.getElementById("speech").width = ImgZoomFactor * obj.width;
    document.getElementById("speech").height = 0.8*ImgZoomFactor * obj.height;

    // get browser window size and scrolling position
    Wsize = getScreenSize();
    Wscroll = getScrollXY();

    // [x,y] stores last location of tooltip window 
    // relative to browser window size and scroll info
    var left = X;
    var top = Y;

    // update location of tooltip window using new scroll information
    left += Wscroll[0]; 
    top += Wscroll[1];
    
    // update location of tooltip window using new window size information
//    left += Wsize[0]/2 - (ImgZoomFactor * obj.width)/2; 
//    top += Wsize[1]/2 - (ImgZoomFactor * obj.height)/2;

    // make tooltip window visible at new location and size 
    tooltipObj.style.top = top;
    tooltipObj.style.left = left;  
    tooltipObj.style.width = ImgZoomFactor * obj.width;
    tooltipObj.style.visibility = "visible";
  }
  
  LargeImage = true;
}


//------------------------------------------------
// Hides the larger image
//------------------------------------------------
function HideLargeImage()
{
  window.clearTimeout(timeID);
  tooltipObj.style.visibility = "hidden";	
  LargeImage = false;
}


//-----------------------------------------------------------
// Is called upon the onkeypress event and processes the key. 
//-----------------------------------------------------------
function Key(e)
{
    // make sure FireFox *and* IE have access to the event object and key code
    if (!e) var e = window.event;
    if (!e.which)
      key = e.keyCode;    
    else if (e.which)
      key = e.which;
      
    // check which key was pressed and process ...  
    switch (key)
    {
    case 45:  // (-)
    case 95:  // (_)
      if (LargeImage)
      {
        ImgZoomFactor = (ImgZoomFactor > MIN_ZOOM) ? ImgZoomFactor-ZOOM_INC : MIN_ZOOM;
        ShowLargeImage();
      }
      break;

    case 43:  // (+)
    case 61:  // (=)
      if (LargeImage)
      {
        ImgZoomFactor = (ImgZoomFactor < MAX_ZOOM) ? ImgZoomFactor+ZOOM_INC : MAX_ZOOM;
        ShowLargeImage();
      }
      break;
      
//    case 76:  // (l)
//    case 108: // (L) (toggles displaying the large image)
    case 27:  // ([esc])
      if (!LargeImage)
      {
        ShowLargeImage();
      }
      else
        HideLargeImage();   
      break;

    case 52:
    case 74:
    case 106:  // cursor left (j,4 NumLock on)
      if (LargeImage)
      {
        if (CurImg > 0) CurImg--;
        ShowLargeImage();
      }
      break;    
      
    case 54:
    case 75:
    case 107:  // cursor right (k,6 NumLock on)
      if (LargeImage)
      {
        CurImg++;
        ShowLargeImage();
      }
      break; 
      
    default:
        // ignore all other keys.
    }
}
